Exclude

Struct Exclude 

pub struct Exclude<T>
where T: Iterator, T::Item: PartialEq,
{ /* private fields */ }
Excludes an object from iteration. Based on a blacklist

Example

use iterators_collection::filter::Exclude;
 
let array = [1, 2, 3, 4, 5];
let iter = array.iter().cloned();
// The iterator will ignore the values 3 and 5
let mut iter = Exclude::with_blacklist(iter, vec![3, 5]);
 
// Once 3 and 5 removed, there are only 1, 2 and 4
assert_eq!(iter.collect::<Vec<i32>>(), vec![1, 2, 4]);

Implementations

Source

impl<T> Exclude<T>
where T: Iterator, T::Item: PartialEq,

pub fn new(iterator: T) -> Self

Returns a new object with an empty blacklist

pub fn with_blacklist(iterator: T, blacklist: Vec<T::Item>) -> Self

Returns a new object with the given blacklist

pub fn exclude(&mut self, new: T::Item)

Adds the object passed as arguments to the blacklist. It will be added only if it is not already inside the blacklist

pub fn force_exclude(&mut self, new: T::Item)

Forces the object passed as arguments to be pushed to the blacklist. It will be added even if already present. You may want to avoid this behaviour and use exclude instead. Use it only if you are sure this element is not in the blacklist or if T::Item is designed as a == b, b == c but a != c. However, it is safe to use it. It may just lead to performance issues

pub fn get_iterator(&self) -> &T

Returns the iterator in use

pub fn get_mut_iterator(&mut self) -> &mut T

Returns the iterator in use as a mutable reference